::--------------------------------------------------
:: Runs this project's Java program(s).
::
:: WARNING: when set the variables below, DO NOT DO A BLANK ASSIGNMENT like set someVar=
:: if someVar is not currently an environmental variable, since in dos that will set errorlevel to 1
::--------------------------------------------------


::----------define global environment variables


@call globalEnvVars.bat
if errorlevel 1 goto handleError


::----------define environment variables specific to this file


set assertions=-enableassertions  -enablesystemassertions
::set assertions=-disableassertions  -disablesystemassertions

::set errorHandling=-XX:+ShowMessageBoxOnError
set errorHandling=-XX:OnError="userdump.exe %%p"
::--------------------CRITICAL: used %%p above because in dos must escape the % char if use it in an env var
::--------------------To understand the above, see:
::	http://java.sun.com/j2se/1.5/pdf/jdk50_ts_guide.pdf Section 3.2.4 starting at page 40 and 121
::	http://support.microsoft.com/?kbid=241215
::	http://download.microsoft.com/download/win2000srv/Utility/3.0/NT45/EN-US/Oem3sr2.zip
::	http://www-128.ibm.com/developerworks/java/library/j-tiger03175.html
set errorHandling=%errorHandling%  -XX:+HeapDumpOnOutOfMemoryError

::--------------------throughput collectors:
::set gcType=-XX:+AggressiveHeap
set gcType=-XX:+UseParallelGC  -XX:+UseParallelOldGC
::--------------------low pause collectors:
::set gcType=-XX:MaxGCPauseMillis=nnn 
::set gcType=-XX:+UseConcMarkSweepGC  -XX:+UseParNewGC
::--------------------gc logging:
::set gcType=-Xloggc:../log/gcLog.txt  -XX:+PrintGCDetails  -XX:+PrintGCTimeStamps
::--------------------documentation on the gc options above:
::	http://java.sun.com/javase/technologies/hotspot/gc/index.jsp
::	http://java.sun.com/javase/technologies/hotspot/gc/gc_tuning_6.html
::	http://java.sun.com/j2se/1.5.0/docs/guide/vm/gc-ergonomics.html
::	http://www.folgmann.de/en/j2ee/gc.html
::	http://java.sun.com/docs/hotspot/gc1.4.2/faq.html

set jni=-Xcheck:jni

::set logConfig=-Djava.util.logging.config.file=./logging.properties
  
::set memory=-Xms64m -Xmx1250m

::set performance=-XX:+AggressiveOpts  -XX:-DoEscapeAnalysis

::set vmType=-client
set vmType=-server

set standardJavaOptions=%assertions%  -classpath %classPath%  %errorHandling%  %gcType%  %jni%  %logConfig%  %memory%  %performance%  %vmType%  -Xfuture


::set profiling=-javaagent:%libDir%/jip-profile.jar


if errorlevel 1 goto handleError


::----------run program(s)


echo on

@echo.
@echo ==================================================

::java  %standardJavaOptions%  N01_Part1_Listing1
::java  %standardJavaOptions%  N02_Part1_Listing2
::java  %standardJavaOptions%  N03_Part1_Listing4
::java  %standardJavaOptions%  N04_Part1_Listing5
::java  %standardJavaOptions%  N05_Part1_Listing7

::java  %standardJavaOptions%  N06_Part2_Figures1and2
::java  %standardJavaOptions%  N07_Part2_Listing1


:: -----N08_Part2_DataStructureAccess; below are the calculations to produce Part 2 Figures 3-5 and Listings 2-3:

@echo off

set arrayClasses=ArrayAccess  ArrayAccessSynchronized
set listClasses=ArrayListAccess  VectorAccess  CopyOnWriteArrayListAccess
set mapClasses=HashMapAccess  HashtableAccess  IdentityHashMapAccess  LinkedHashMapAccess  TreeMapAccess  WeakHashMapAccess  ConcurrentHashMapAccess1  ConcurrentHashMapAccess16  ConcurrentSkipListMapAccess  ThreadLocalAccess
set classes=%arrayClasses%  %listClasses%  %mapClasses%

set modes=sequential random

set sizes=1024 1048576

set pathPrefix=-pathPrefix ../results/newPostArticleResults/N08_Part2_DataStructureAccess/normalOptions/XeonE5420
::set pathPrefix=-pathPrefix ../results/newPostArticleResults/N08_Part2_DataStructureAccess/performanceOptions/XeonE5420
::set pathPrefix=-pathPrefix ../results/newPostArticleResults/N08_Part2_DataStructureAccess/unmodifiable/XeonE5420

for %%m in (%modes%) do (
	for %%s in (%sizes%) do (
		for %%c in (%classes%) do (
			echo --------------------------------------------------
			echo class = %%c,  mode = %%m,  size = %%s
			java  %standardJavaOptions%  N08_Part2_DataStructureAccess  -class %%c  -mode %%m  -size %%s  %pathPrefix%
		)
	)
)


:: -----N08_Part2_DataStructureAccess; below are the calculations to investigate the ConcurrentHashMap anomaly:

::@echo off

::set classes=ConcurrentHashMapAccess1  ConcurrentHashMapAccess16

::set modes=sequential random

::set sizes=2 3 5 8 12 19 31 48 76 119 188 295 465 733 1154 1817 2862 4507 7098 11177 17602 27720 43653 68745 108260 170488 268485 422812 665845 1048576
::	NOTE: the sizes above are an approximate geometric series (chosen because a log scale plot then has a uniform density); were originally generated by executing N08_Part2_DataStructureAccess in a special mode (see the source code of its main method; need to uncomment 3 lines)

::set pathPrefix=-pathPrefix ../results/newPostArticleResults/N08_Part2_DataStructureAccess_ConcurrentHashMapAnomaly/XeonE5420

::for %%m in (%modes%) do (
::	for %%s in (%sizes%) do (
::		for %%c in (%classes%) do (
::			echo --------------------------------------------------
::			echo class = %%c,  mode = %%m,  size = %%s
::			java  %standardJavaOptions%  N08_Part2_DataStructureAccess  -class %%c  -mode %%m  -size %%s  %pathPrefix%
::		)
::	)
::)


:: -----single arg invocations cause calls to N09_Part2_PortfolioOptimization.test_manyFunctionalities:
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_australianFunds_monthly_2005-2007.txt
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_monthly_2005-2007.txt
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_weekly_2005-2007.txt
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_vanguard_yearly_1998-2007.txt
:: -----double arg invocations cause calls to N09_Part2_PortfolioOptimization.benchmark_efficientFrontier:
:: ----------no constraints:
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_australianFunds_monthly_2005-2007.txt  NOConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_monthly_2005-2007.txt  NOConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_weekly_2005-2007.txt  NOConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_vanguard_yearly_1998-2007.txt  NOConstraints
:: ----------constraints:
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_australianFunds_monthly_2005-2007.txt  useConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_monthly_2005-2007.txt  useConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_oex_weekly_2005-2007.txt  useConstraints
::java  %standardJavaOptions%  N09_Part2_PortfolioOptimization  ../data/returns_vanguard_yearly_1998-2007.txt  useConstraints

::java  %standardJavaOptions%  N10_Supplement_Lfsr
::java  %standardJavaOptions%  N11_Supplement_LfsrVariations
::java  %standardJavaOptions%  N12_Supplement_Listing3
::java  %standardJavaOptions%  N13_Supplement_CallableVersusRunnable


:: -----N14_Extra_DataStructureIteration; below are the calculations to investigate iteration performance:

::@echo off

::set arrayClasses=ArrayIteration  ArrayIterationSynchronized
::set listClasses=ArrayListIteration  LinkedListIteration  StackIteration  VectorIteration  CopyOnWriteArrayListIteration
::set setClasses=HashSetIteration  LinkedHashSetIteration  TreeSetIteration  ConcurrentSkipListSetIteration  CopyOnWriteArraySetIteration
::set queueClasses=ArrayBlockingQueueIteration  ConcurrentLinkedQueueIteration  LinkedBlockingQueueIteration  PriorityBlockingQueueIteration  PriorityQueueIteration
::set dequeClasses=ArrayDequeIteration  LinkedBlockingDequeIteration
::set mapClasses=HashMapIteration  HashtableIteration  IdentityHashMapIteration  LinkedHashMapIteration  TreeMapIteration  WeakHashMapIteration  ConcurrentHashMapIteration1  ConcurrentHashMapIteration16  ConcurrentSkipListMapIteration
::set classes=%arrayClasses%  %listClasses%  %setClasses%  %queueClasses%  %dequeClasses%  %mapClasses%

::set sizes=1024 1048576

::set pathPrefix=-pathPrefix ../results/newPostArticleResults/N14_Extra_DataStructureIteration/normalOptions/XeonE5420
::set pathPrefix=-pathPrefix ../results/newPostArticleResults/N14_Extra_DataStructureIteration/performanceOptions/XeonE5420
::set pathPrefix=-pathPrefix ../results/newPostArticleResults/N14_Extra_DataStructureIteration/unmodifiable/XeonE5420

::for %%s in (%sizes%) do (
::	for %%c in (%classes%) do (
::		echo --------------------------------------------------
::		echo class = %%c,  size = %%s
::		java  %standardJavaOptions%  N14_Extra_DataStructureIteration  -class %%c  -size %%s  %pathPrefix%
::	)
::)


:: -----N15_Extra_ArrayRandomAccessVersusSize; below are the calculations to determine CPU cache sizes:

::@echo off

::set sizes=2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 19 20 22 24 26 28 30 33 36 39 42 45 49 53 58 63 68 74 80 86 94 101 110 119 129 140 151 164 178 192 208 226 245 265 287 311 337 365 396 429 464 503 545 591 640 693 751 814 882 955 1035 1121 1215 1316 1426 1545 1673 1813 1964 2128 2305 2498 2706 2932 3176 3441 3728 4039 4376 4741 5137 5565 6029 6532 7077 7667 8307 9000 9750 10564 11445 12399 13434 14554 15768 17083 18508 20052 21724 23537 25500 27627 29931 32427 35132 38062 41237 44677 48403 52440 56814 61553 66687 72250 78276 84805 91878 99542 107844 116840 126585 137143 148582 160976 174402 188949 204709 221784 240282 260324 282038 305562 331049 358661 388577 420987 456101 494144 535360 580014 628393 680806 737591 799113 865766 937979 1016215 1100976 1192807 1292298 1400087 1516867 1643387 1780461 1928967 2089860 2264173 2453025 2657629 2879299 3119459 3379650 3661542 3966948 4297827 4656304 5044681 5465453 5921320 6415211 6950297 7530014 8158084 8838541 9575755 10374458 11239781 12177279 13192973 14293384 15485580 16777216
::	NOTE: the sizes above are an approximate geometric series (chosen because a log scale plot then has a uniform density); were originally generated by executing N15_Extra_ArrayRandomAccessVersusSize in a special mode (see the source code of its main method; need to uncomment 3 lines)

::set pathPrefix=-pathPrefix ../results/newPostArticleResults/N15_Extra_ArrayRandomAccessVersusSize/XeonE5420

::for %%s in (%sizes%) do (
::	echo --------------------------------------------------
::	echo size = %%s
::	java  %standardJavaOptions%  N15_Extra_ArrayRandomAccessVersusSize  -size %%s  %pathPrefix%
::)


@if errorlevel 1 goto handleError

@echo off

:: TO DO CODE PROFILING, read: D:\software\java\docsGroupedByTopic\performance\profiling.txt


::----------error handling and final actions:


:handleError
@if not errorlevel 1 goto finalActions
@echo.
@echo ERROR DETECTED: jr.bat will TERMINATE PREMATURELY

:finalActions
@echo off
