/*
Copyright  2008 Brent Boyer

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public License for more details.

You should have received a copy of the Lesser GNU General Public License along with this program (see the license directory in this project).  If not, see <http://www.gnu.org/licenses/>.
*/


/**
* For the article <a href="http://www.ibm.com/developerworks/java/library/j-benchmark1.html">Robust Java benchmarking, Part 1: Issues</a>,
* contains the code relevant to <a href="http://www.ibm.com/developerworks/java/library/j-benchmark1.html#listing4">Listing 4</a>.
* <p>
* @author Brent Boyer
*/
public class N03_Part1_Listing4 {
	
	
	protected static final int[] array = new int[10 * 1000];
	static {
		for (int i = 0; i < array.length; i++) {
			array[i] = i;
		}
	}
	
	
	/**
	* Results on 2008-03-27 on my 2.2 GHz Intel Core 2 Duo E4500 machine (server jvm):
	* <pre><code>
		Execution time = 21.61... seconds to compute result = 1580674560
		Execution time = 21.61... seconds to compute result = 1580674560
		Execution time = 21.60... seconds to compute result = 1580674560
	</code></pre>
	*/
	public static void main(String[] args) {
		System.out.println();
		System.out.println("N03_Part1_Listing4:");
		
		long t1 = System.nanoTime();
		
		int result = 0;
		for (int i = 0; i < 1000 * 1000; i++) {	// outer loop
			for (int j = 0; j < array.length; j++) {	// inner loop 1
				result += array[j];
			}
			for (int j = 0; j < array.length; j++) {	// inner loop 2
				result ^= array[j];
			}
		}
		
		long t2 = System.nanoTime();
		System.out.println("Execution time = " + ((t2 - t1) * 1e-9) + " seconds to compute result = " + result);
	}
	
	
}
