/*
Copyright  2008 Brent Boyer

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public License for more details.

You should have received a copy of the Lesser GNU General Public License along with this program (see the license directory in this project).  If not, see <http://www.gnu.org/licenses/>.
*/


import bb.science.Math2;


/**
* For the article <a href="http://www.ibm.com/developerworks/library/j-benchmark2/index.html">Robust Java benchmarking, Part 2: Statistics And solutions</a>,
* contains the code relevant to <a href="http://www.ibm.com/developerworks/library/j-benchmark2/index.html#fig1">Figure 1</a>
* and <a href="http://www.ibm.com/developerworks/library/j-benchmark2/index.html#fig2">Figure 2</a>.
* <p>
* @author Brent Boyer
*/
public class N06_Part2_Figures1and2 {
	
	
	/**
	* Results on 2008-04-30 on my 2.2 GHz Intel Core 2 Duo E4500 machine (server jvm):
	* see the file ../results/N06_Part2_Figures1and2.xls.
	*/
	public static void main(String[] args) {
		System.out.println();
		System.out.println("N06_Part2_Figures1and2:");
		
			// Gaussian parameters for Figure 1 (both curves are Gaussian PDFs):
		double mu1a = 1.0;
		double mu1b = 1.1;
		double sd1a = (mu1b - mu1a) / 5.0;
		double sd1b = (mu1b - mu1a) / 20.0;
			// Gaussian parameters for Figure 2:
		double mu2a = mu1a;
		double mu2b = 1.05;
		double sd2a = (mu1b - mu1a) / 2.0;
		double sd2b = sd1b;
			// x-axis:
		double xMin = mu1a - (3 * sd2a);
		double xMax = mu1b + (3 * sd2a);
		double xDelta = (xMax - xMin) / 200.0;
		
		System.out.println("x" + "\t" + "pdf1a" + "\t" + "pdf1b" + "\t" + "pdf2a" + "\t" + "pdf2b");
		for (double x = xMin; x <= xMax; x += xDelta) {
			System.out.println(x + "\t" + Math2.gaussianPdf(x, mu1a, sd1a) + "\t" + Math2.gaussianPdf(x, mu1b, sd1b) + "\t" + Math2.gaussianPdf(x, mu2a, sd2a) + "\t" + Math2.gaussianPdf(x, mu2b, sd2b));
		}
	}
	
	
}
