/*
Copyright  2008 Brent Boyer

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public License for more details.

You should have received a copy of the Lesser GNU General Public License along with this program (see the license directory in this project).  If not, see <http://www.gnu.org/licenses/>.
*/


import bb.util.Benchmark;
import java.util.concurrent.Callable;


/**
* For the article <a href="http://www.ibm.com/developerworks/library/j-benchmark2/index.html">Robust Java benchmarking, Part 2: Statistics And solutions</a>,
* contains the code relevant to <a href="http://www.ibm.com/developerworks/library/j-benchmark2/index.html#listing1">Listing 1</a>.
* <p>
* @author Brent Boyer
*/
public class N07_Part2_Listing1 {
	
	
	/**
	* Results on 2008-03-27 on my 2.2 GHz Intel Core 2 Duo E4500 machine (server jvm):
	* <pre><code>
		fibonacci(35): first = 106.857 ms, mean = 102.570 ms (CI deltas: -35.185 us, +47.076 us), sd = 645.586 us (CI deltas: -155.465 us, +355.098 us) WARNING: EXECUTION TIMES HAVE EXTREME OUTLIERS, SD VALUES MAY BE INACCURATE
	</code></pre>
	*/
	public static void main(String[] args) throws Exception {
		System.out.println();
		System.out.println("N07_Part2_Listing1");
		
		Callable<Integer> task = new Callable<Integer>() { public Integer call() { return fibonacci(35); } };
		System.out.println("fibonacci(35): " + new Benchmark(task));
	}
	
	
	/** Calculates and returns the nth Fibonacci number using a simple recursive algorithm. */
	protected static int fibonacci(int n) throws IllegalArgumentException {
		if (n < 0) throw new IllegalArgumentException("n = " + n + " < 0");
		if (n <= 1) return n;
		return fibonacci(n - 1) + fibonacci(n - 2);
	}
	
	
}
