/*
Copyright  2008 Brent Boyer

This program is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the Lesser GNU General Public License for more details.

You should have received a copy of the Lesser GNU General Public License along with this program (see the license directory in this project).  If not, see <http://www.gnu.org/licenses/>.
*/


import bb.util.Benchmark;


/**
* For the <a href="http://www.ellipticgroup.com/html/benchmarkingArticle.html">article supplement</a>,
* contains the code relevant to Figure 1 and Figure 2.
* <p>
* @author Brent Boyer
*/
public class N11_Supplement_LfsrVariations {
	
	
	/**
	* Results on 2008-03-27 on my 2.2 GHz Intel Core 2 Duo E4500 machine (server jvm):
	* see the file <code>../results/N11_Supplement_LfsrVariations.xls</code>.
	* This contains all of the data, plus all of the associated Figures in the article.
	*/
	public static void main(String[] args) throws Exception {
		System.out.println();
		System.out.println("N11_Supplement_LfsrVariations:");
		
		Runnable task = new Benchmark.LfsrAdvancer();	// Benchmark.LfsrAdvancer is actually defined inside Benchmark because it is used to measure noise floors
		
		Benchmark.Params params = new Benchmark.Params();
		//params.setMeasureCpuTime(true);	// default is false: measure elapsed time
		
		Benchmark2 benchmark2 = new Benchmark2(task, params);	// this will do all the warmups etc
		System.out.println(benchmark2.toStringFull());
		
		System.out.println("numberExecutions" + "\t" + "meanBlock" + "\t" + "sdBlock" + "\t" + "meanAction" + "\t" + "sdAction");
			// first loop: increase numberExecutions linearly by 1 each iteration:
		for (int i = 1; i < 51; i++) {
			System.out.println( benchmark2.perform(i) );
		}
			// second loop: increase numberExecutions exponentially by 2^(1/5) longer each iteration (i.e. so double numberExecutions every 5 loops):
		double constant = 50;
		double base = Math.pow(2.0, 1.0/5.0);
		for (int i = 1; i <= 9*5; i++) {
			long n = Math.round( constant * Math.pow(base, i) );
			System.out.println( benchmark2.perform(n) );
		}
	}
	
	
	/**
	* Specialized subclass of Benchmark which has an additional <code>perform</code> method
	* which will support the calculaations and results needed by the parent class.
	*/
	protected static class Benchmark2 extends Benchmark {
		
		protected Benchmark2(Runnable task, Benchmark.Params params) {
			super(task, params);
		}
		
		protected String perform(long numberExecutions) throws Exception {
			this.numberExecutions = numberExecutions;
			doMeasurements();
			calculateStats();
			return numberExecutions + "\t" + getStatsBlock().getMean() + "\t" + getStatsBlock().getSd() + "\t" + getMean() + "\t" + getSd();
		}
		
	}
	
}
